Task: Persona-Chat
===================
Description: A chit-chat dataset where paired Turkers are given assigned personas and chat to try to get to know each other. See the paper: https://arxiv.org/abs/1801.07243

Tags: #Persona-Chat, #ChitChat, #All

